pub struct DateSelector {
pub name: String,
pub has_time: bool,
/* private fields */
}Expand description
The interactive selector interface for date and time.
By default, DateSelector::new() returns a selector for date, NOT FOR date and time.
If you want to select date and time with a selector, set DateSelector.has_time true
before calling select() method.
An instance for the date selection must be mutable and the selected date (or datetime) can be extracted within different formats:
- DateSelector.get_date() ->
chrono::DateTime<Local> - DateSelector.to_string() -> String
use ttyui::selector::DateSelector;
let mut d = DateSelector::new();
d.has_time = true;
println!("selected: {}", d.select().unwrap().to_string());Fields
name: Stringdate name for the selection
has_time: boolwhether the selector supports time selection or not
Implementations
Sourceimpl DateSelector
impl DateSelector